Name:       barman
Version:    3.0.1
Release:    1%{?dist}
Summary:    Backup and Recovery Manager for PostgreSQL
License:    GPLv3
URL:        http://www.pgbarman.org/
BuildArch:  noarch

Source0:    https://files.pythonhosted.org/packages/source/b/%{name}/%{name}-%{version}.tar.gz
Source1:    %{name}.cron
Source2:    %{name}.logrotate

BuildRequires:  python2-devel
BuildRequires:  python2-setuptools

# https://docs.fedoraproject.org/en-US/packaging-guidelines/CronFiles/#_cron_job_files_packaging:
Requires:       cronie
Requires:       logrotate
Requires(pre):  shadow-utils
Requires:       rsync >= 3.0.4
Requires:       python2-argcomplete
Requires:       python2-barman = %{version}

%description
Barman (Backup and Recovery Manager) is an open-source administration tool for
disaster recovery of PostgreSQL servers written in Python.

It allows your organization to perform remote backups of multiple servers in
business critical environments to reduce risk and help DBAs during the recovery
phase.

%package cli
Summary:    Client Utilities for Barman
Requires:   python2-barman = %{version}

%description cli
Client utilities for the integration of Barman in PostgreSQL clusters.

%package -n python2-barman
Summary:    Shared libraries for Barman
Requires:   python-dateutil
Requires:   python-psycopg2 >= 2.4.2
Requires:   python2-argh >= 0.21.2
Requires:   python2-setuptools

%description -n python2-barman
Python libraries used by Barman.

%prep
%autosetup

# Change shebang in all relevant executable files in this directory and all subdirectories
find -type f -executable -exec sed -i '1s=^#!/usr/bin/\(python\|env python\)[23]\?=#!%{__python2}=' {} +

%build
%py2_build

%install
%py2_install

mkdir -p %{buildroot}%{_sysconfdir}/%{name}/conf.d
mkdir -p %{buildroot}%{_sysconfdir}/cron.d/
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/

install -p -m 644 doc/%{name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -p -m 644 doc/%{name}.d/* %{buildroot}%{_sysconfdir}/%{name}/conf.d
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/cron.d/%{name}
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -p -m 644 scripts/%{name}.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}

sed -i 's|/etc/%{name}.d|/etc/%{name}/conf.d|g' %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

%files
%{_bindir}/%{name}
%{_datadir}/bash-completion/completions/%{name}
%{_mandir}/man1/%{name}.1*
%{_mandir}/man5/%{name}.5*
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/conf.d/
%config(noreplace) %{_sysconfdir}/cron.d/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(700,%{name},%{name}) %dir %{_sharedstatedir}/%{name}
%attr(755,%{name},%{name}) %dir %{_localstatedir}/log/%{name}

%files cli
%{_bindir}/%{name}-cloud-backup
%{_bindir}/%{name}-cloud-backup-delete
%{_bindir}/%{name}-cloud-backup-keep
%{_bindir}/%{name}-cloud-backup-list
%{_bindir}/%{name}-cloud-check-wal-archive
%{_bindir}/%{name}-cloud-restore
%{_bindir}/%{name}-cloud-wal-archive
%{_bindir}/%{name}-cloud-wal-restore
%{_bindir}/%{name}-wal-archive
%{_bindir}/%{name}-wal-restore
%{_mandir}/man1/%{name}-cloud-backup.1*
%{_mandir}/man1/%{name}-cloud-backup-delete.1.gz
%{_mandir}/man1/%{name}-cloud-backup-keep.1.gz
%{_mandir}/man1/%{name}-cloud-backup-list.1*
%{_mandir}/man1/%{name}-cloud-check-wal-archive.1.gz
%{_mandir}/man1/%{name}-cloud-restore.1*
%{_mandir}/man1/%{name}-cloud-wal-archive.1*
%{_mandir}/man1/%{name}-cloud-wal-restore.1*
%{_mandir}/man1/%{name}-wal-archive.1*
%{_mandir}/man1/%{name}-wal-restore.1*

%files -n python2-%{name}
%license LICENSE
%doc NEWS README.rst
%{python2_sitelib}/%{name}-%{version}-py%{python2_version}.egg-info
%{python2_sitelib}/%{name}/

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sharedstatedir}/%{name} -s /bin/bash \
    -c "Backup and Recovery Manager for PostgreSQL" %{name}
exit 0

%changelog
* Sat Jul 09 2022 Simone Caronni <negativo17@gmail.com> - 3.0.1-1
- Update to 3.0.1.

* Sat Jul 09 2022 Simone Caronni <negativo17@gmail.com> - 3.0.0-1
- Update to 3.0.0.

* Fri Dec 31 2021 Simone Caronni <negativo17@gmail.com> - 2.17-1
- Update to 2.17.

* Sun Nov 22 2020 Francisco Javier Tsao Santín <tsao@disroot.org> - 2.12-1
- Update to 2.12.

* Tue Aug 18 2020 Simone Caronni <negativo17@gmail.com> - 2.11-1
- Update to 2.11.

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.10-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jul 02 2020 Simone Caronni <negativo17@gmail.com> - 2.10-5
- Require cronie, not crontabs.

* Wed Jul 01 2020 Simone Caronni <negativo17@gmail.com> - 2.10-4
- Import from master, update to 2.10 and update SPEC file.
- Use macros where possible.
- Adjust Python requirements for Python 2.
- Install license and docs in python libraries, so they are always installed.
- Do not remove logs on uninstallation.
- Trim changelog.

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-10
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Nov 14 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.3.3-8
- Update requires on python-argcomplete
- Move completion script to /usr

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Feb 17 2015 - Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.3.3-6
- Revert dependency on python-dateutil15 (#1183341)

* Mon Feb 02 2015 - Dale Macartney <dbmacartney@fedoraproject.org> - 1.3.3-5
- Replacing python-dateutil with python-dateutil15

* Wed Jan 21 2015 - Dale Macartney <dbmacartney@fedoraproject.org> - 1.3.3-4
- Resolve RPM dependencies with older version of python-dateutil

* Wed Jan 14 2015 - Dale Macartney <dbmacartney@fedoraproject.org> - 1.3.3-3
- Update barman to 1.3.3

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Apr 15 2014 - Dale Macartney <dbmacartney@fedoraproject.org> 1.3.1-1
- Update barman to 1.3.1

* Tue Feb 4 2014 - Dale Macartney <dbmacartney@fedoraproject.org> 1.3.0-1
- Update barman to 1.3.0

* Wed Jan 15 2014 - Dale Macartney <dbmacartney@fedoraproject.org> 1.2.3-9
- Corrected rpmlint warning permissions

* Tue Jan 14 2014 - Dale Macartney <dbmacartney@fedoraproject.org> 1.2.3-7
- Change license from GPLv3 to GPLv3+

* Mon Jan 13 2014 - Dale Macartney <dbmacartney@fedoraproject.org> 1.2.3-6
- Clean up of rpmlint errors

* Mon Jan 13 2014 - Dale Macartney <dbmacartney@fedoraproject.org> 1.2.3-5
- Remove non-required variables for older fedora/rhel releases.

* Wed Oct 16 2013 - Dale Macartney <dbmacartney@gmail.com> 1.2.3-4
- Clean up of package dependencies and removal of unnecessary variables

* Thu Oct 10 2013 - Dale Macartney <dbmacartney@gmail.com> 1.2.3-1
- Initial packaging for Fedora Project
